#######################
PyDMEnumButton
#######################

.. autoclass:: pydm.widgets.enum_button.PyDMEnumButton
   :members:
   :show-inheritance:

.. note::
   See `QWidget Documentation <https://doc.qt.io/qtforpython-5/PySide2/QtWidgets/QWidget.html>`_ for all inherited properties and methods.